@@ -37,7 +37,7 @@ SESSION = None
 async def generate_session(profile: schemas.Profile) -> Any:
     auth_url = await get_endpoint(
         region=profile.region,
-        service="keystone",
+        service="identity",
         session=get_system_session(),
     )
     kwargs = {
@@ -46,7 +46,7 @@ async def generate_session(profile: schemas.Profile) -> Any:
         "project_id": profile.project.id,
     }
     auth = Token(**kwargs)
-    session = Session(auth=auth, verify=False, timeout=constants.DEFAULT_TIMEOUT)
+    session = Session(auth=auth, verify=CONF.default.cafile, timeout=constants.DEFAULT_TIMEOUT)
     session.auth.auth_ref = await run_in_threadpool(session.auth.get_auth_ref, session)
     return session
 
@@ -65,14 +65,16 @@ def get_system_session() -> Session:
         project_domain_name=CONF.openstack.system_project_domain,
         reauthenticate=True,
     )
-    SESSION = Session(auth=auth, verify=False, timeout=constants.DEFAULT_TIMEOUT)
+    SESSION = Session(auth=auth, verify=CONF.default.cafile, timeout=constants.DEFAULT_TIMEOUT)
     return SESSION
 
 
 async def get_system_scope_access(keystone_token: str, region: str) -> AccessInfoV3:
-    auth_url = await get_endpoint(region, "keystone", get_system_session())
+    auth_url = await get_endpoint(region, "identity", get_system_session())
     scope_auth = Token(auth_url, keystone_token, system_scope="all")
-    session = Session(auth=scope_auth, verify=False, timeout=constants.DEFAULT_TIMEOUT)
+    session = Session(
+        auth=scope_auth, verify=CONF.default.cafile, timeout=constants.DEFAULT_TIMEOUT
+    )
     return await run_in_threadpool(session.auth.get_auth_ref, session)
 
 
@@ -88,7 +90,7 @@ async def get_endpoint(region: str, service: str, session: Session) -> Any:
     service_catalog = access.service_catalog
     endpoint = service_catalog.get_urls(
         region_name=region,
-        service_name=service,
+        service_type=service,
         interface=CONF.openstack.interface_type,
     )
     if not endpoint:
@@ -102,7 +104,7 @@ async def keystone_client(
     global_request_id: Optional[str] = None,
     version: str = constants.KEYSTONE_API_VERSION,
 ) -> HTTPClient:
-    endpoint = await get_endpoint(region, "keystone", session=session)
+    endpoint = await get_endpoint(region, "identity", session=session)
     client = KeystoneClient(
         version=version,
         session=session,
@@ -119,7 +121,7 @@ async def glance_client(
     global_request_id: Optional[str] = None,
     version: str = constants.GLANCE_API_VERSION,
 ) -> HTTPClient:
-    endpoint = await get_endpoint(region, "glance", session=session)
+    endpoint = await get_endpoint(region, "image", session=session)
     client = GlanceClient(
         version=version,
         session=session,
@@ -135,7 +137,7 @@ async def nova_client(
     global_request_id: Optional[str] = None,
     version: str = constants.NOVA_API_VERSION,
 ) -> HTTPClient:
-    endpoint = await get_endpoint(region, "nova", session=session)
+    endpoint = await get_endpoint(region, "compute", session=session)
     client = NovaClient(
         version=version,
         session=session,
@@ -151,7 +153,7 @@ async def cinder_client(
     global_request_id: Optional[str] = None,
     version: str = constants.CINDER_API_VERSION,
 ) -> HTTPClient:
-    endpoint = await get_endpoint(region, "cinderv3", session=session)
+    endpoint = await get_endpoint(region, "volumev3", session=session)
     client = CinderClient(
         version=version,
         session=session,
@@ -167,7 +169,7 @@ async def neutron_client(
     global_request_id: Optional[str] = None,
     version: str = constants.NEUTRON_API_VERSION,
 ) -> HTTPClient:
-    endpoint = await get_endpoint(region, "neutron", session=session)
+    endpoint = await get_endpoint(region, "network", session=session)
     client = NeutronClient(
         version=version,
         session=session,
